.. currentmodule:: sardana.sardanacontainer

:mod:`~sardana.pool.sardanacontainer`
=====================================

.. automodule:: sardana.sardanacontainer

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`SardanaContainer`


SardanaContainer
----------------

.. inheritance-diagram:: SardanaContainer
    :parts: 1
    
.. autoclass:: SardanaContainer
    :inherited-members:
    :members:
    :undoc-members:
    
